@@ -1,5 +1,5 @@
 /*
- * GTK See -- a image viewer based on GTK+
+ * GTK See -- an image viewer based on GTK+
  * Copyright (C) 1998 Hotaru Lee <jkhotaru@mail.sti.com.cn> <hotaru@163.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,12 +26,17 @@
 
 #include <gtk/gtk.h>
 
-gboolean	get_current_image	(gchar *buffer);
-void		refresh_list		();
-void		refresh_all		();
-void		show_browser		();
-void		gtksee_set_root		(guchar *new_root);
-void		gtksee_main		();
+gboolean get_current_image  (gchar *buffer);
+void     refresh_list       ();
+void     refresh_all        ();
+void     show_browser       ();
+void     gtksee_set_root    (guchar *new_root);
+void     menu_edit_rename   (GtkWidget *widget, gpointer data);
+void     menu_edit_timestamp(GtkWidget *widget, gpointer data);
+void     menu_edit_delete   (GtkWidget *widget, gpointer data);
+void     menu_help_contents (GtkWidget *widget, gpointer data);
+void     menu_help_about    (GtkWidget *widget, gpointer data);
+void     gtksee_main        ();
 
 #ifdef __cplusplus
         }
