@@ -1,5 +1,5 @@
 /*
- * GTK See -- a image viewer based on GTK+
+ * GTK See -- an image viewer based on GTK+
  * Copyright (C) 1998 Hotaru Lee <jkhotaru@mail.sti.com.cn> <hotaru@163.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef __GTKSEEABOUT_H__
 #define __GTKSEEABOUT_H__
 
@@ -26,7 +26,11 @@
 
 #include <gtk/gtk.h>
 
-GtkWidget*	get_about_dialog	();
+#define ABOUT     1
+#define CONTENTS  2
+
+void  generate_dialog    (gchar type);
+void  print_help_message ();
 
 #ifdef __cplusplus
         }
