@@ -1,5 +1,5 @@
 /*
- * GTK See -- a image viewer based on GTK+
+ * GTK See -- an image viewer based on GTK+
  * Copyright (C) 1998 Hotaru Lee <jkhotaru@mail.sti.com.cn> <hotaru@163.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,21 +21,23 @@
 #define __GTKSEESTATUS_H__
 
 #ifdef __cplusplus
-	extern "C" {
+   extern "C" {
 #endif /* __cplusplus */
 
 #include <gtk/gtk.h>
 
-GtkWidget*	get_main_status_bar	(GdkPixmap *pixmap,
-					 GdkBitmap *mask);
-void		set_status_main		(gchar *text);
-void		set_status_file		(gchar *text);
-void		set_status_type		(GdkPixmap *pixmap, GdkBitmap *mask);
-void		set_status_name		(gchar *text);
-void		set_status_prop		(gchar *text);
+GtkWidget*  get_main_status_bar  (GdkPixmap *pixmap, GdkBitmap *mask);
+void        set_status_main      (gchar *text);
+void        set_status_file      (gchar *text);
+void        set_status_type      (GdkPixmap *pixmap, GdkBitmap *mask);
+void        set_status_name      (gchar *text);
+void        set_status_prop      (gchar *text);
+void        start_progress_data  ();
+void        stop_progress_data   ();
+void        update_progress_data (gulong count, gulong counter_end);
 
 #ifdef __cplusplus
-	}
+   }
 #endif /* __cplusplus */
 
 #endif
