@@ -1,5 +1,5 @@
 /*
- * GTK See -- a image viewer based on GTK+
+ * GTK See -- an image viewer based on GTK+
  * Copyright (C) 1998 Hotaru Lee <jkhotaru@mail.sti.com.cn> <hotaru@163.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -195,7 +195,7 @@ png_load(gchar *filename, PngLoadFunc func)
          bpp = 2;
          break;
       case PNG_COLOR_TYPE_PALETTE :       /* Indexed */
-         bpp = 3;
+         bpp = info->num_trans ? 4:3;
          break;
    };
 
