@@ -1,5 +1,5 @@
 /*
- * GTK See -- a image viewer based on GTK+
+ * GTK See -- an image viewer based on GTK+
  * Copyright (C) 1998 Hotaru Lee <jkhotaru@mail.sti.com.cn> <hotaru@163.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,25 +21,26 @@
 #define __IM_PNM_H__
 
 #ifdef __cplusplus
-	extern "C" {
+   extern "C" {
 #endif /* __cplusplus */
 
 #include <gtk/gtk.h>
 
 typedef struct pnm_info_struct
 {
-	gint width;
-	gint height;
-	gint ncolors;
+   gint width;
+   gint height;
+   gint ncolors;
+   gint maxcolor;
 } pnm_info;
 
-typedef	gboolean	(*PnmLoadFunc)		(guchar *buffer, gint width, gint left, gint scanline, gint components, gint pass, gint mode);
+typedef  gboolean (*PnmLoadFunc)    (guchar *buffer, gint width, gint left, gint scanline, gint components, gint pass, gint mode);
 
-gboolean	pnm_get_header		(gchar *filename, pnm_info *info);
-gboolean	pnm_load		(gchar *filename, PnmLoadFunc func);
+gboolean pnm_get_header    (gchar *filename, pnm_info *info);
+gboolean pnm_load    (gchar *filename, PnmLoadFunc func);
 
 #ifdef __cplusplus
-	}
+   }
 #endif /* __cplusplus */
 
 #endif
