@@ -1,5 +1,5 @@
 /*
- * GTK See -- a image viewer based on GTK+
+ * GTK See -- an image viewer based on GTK+
  * Copyright (C) 1998 Hotaru Lee <jkhotaru@mail.sti.com.cn> <hotaru@163.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -284,7 +284,7 @@ options_ok(GtkWidget *window)
 	interval = atoi(gtk_entry_get_text(
 		GTK_ENTRY(slideshow_interval_entry)));
 	rc_set_int(interval_rc, interval);
-	rc_save_gtkseerc();
+	
 	if (need_refresh)
 	{
 		refresh_all();
